@@ -63,7 +63,7 @@ HackaMol::X::Calculator - Abstract calculator class for HackaMol
 
 =head1 VERSION
 
-version 0.00_6
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -94,9 +94,9 @@ version 0.00_6
    sub output_map {
        my $calc = shift;
        my $conv = shift;
-       my $out  = $calc->out_fn->slurp;
-       $out =~ m /SCF Done:.*(-\d+.\d+)/;
-       return ( $1 * $conv );
+       my $re   = qr/-\d+.\d+/;
+       my @energys = $calc->out_fn->slurp =~ m/SCF Done:.*(${re})/g;
+       return ( $energys[-1] * $conv );
    }
 
 =head1 DESCRIPTION
@@ -174,7 +174,7 @@ Demian Riccardi <demianriccardi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Demian Riccardi.
+This software is copyright (c) 2015 by Demian Riccardi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
